Comparison Table · Chart.js documentation
Author: chartjs

# Comparison with Other Charting Libraries

Library Features

Feature | Chart.js | D3 | HighCharts | Chartist
--- | --- | --- | --- | ---
Completely Free | ✓ | ✓ |  | ✓
Canvas | ✓ |  |  |
SVG |  | ✓ | ✓ | ✓
Built-in Charts | ✓ |  | ✓ | ✓
8+ Chart Types | ✓ | ✓ | ✓ |
Extendable to Custom Charts | ✓ | ✓ |  |
Supports Modern Browsers | ✓ | ✓ | ✓ | ✓
Extensive Documentation | ✓ | ✓ | ✓ | ✓
Open Source | ✓ | ✓ |  | ✓

Built in Chart Types

Type | Chart.js | HighCharts | Chartist
--- | --- | --- | ---
Combined Types | ✓ | ✓ |
Line | ✓ | ✓ | ✓
Bar | ✓ | ✓ | ✓
Horizontal Bar | ✓ | ✓ | ✓
Pie/Doughnut | ✓ | ✓ | ✓
Polar Area | ✓ | ✓ |
Radar | ✓ |  |
Scatter | ✓ | ✓ | ✓
Bubble | ✓ |  |
Gauges |  | ✓ |
Maps (Heat/Tree/etc.) |  | ✓

# results matching ""

# No results matching ""